searchData={"items":[{"type":"module","title":"TestServer","doc":"No fuzz ExUnit test server to mock third party services.\n\nFeatures:\n\n- HTTP/1\n- HTTP/2\n- WebSocket\n- Built-in TLS with self-signed certificates\n- Plug route matching","ref":"TestServer.html"},{"type":"module","title":"Usage - TestServer","doc":"Add route request expectations with `TestServer.add/2`:\n\n```elixir\ntest \"fetch_url/0\" do\n  # The test server will autostart the current test server, if not already running\n  TestServer.add(\"/\", via: :get)\n\n  # The URL is derived from the current test server instance\n  Application.put_env(:my_app, :fetch_url, TestServer.url())\n\n  {:ok, \"HTTP\"} = MyModule.fetch_url()\nend\n```\n\n`TestServer.add/2` can route a request to an anonymous function or plug with `:to` option.\n\n```elixir\nTestServer.add(\"/\", to: fn conn ->\n  Plug.Conn.send_resp(conn, 200, \"OK\")\nend)\n\nTestServer.add(\"/\", to: MyPlug)\n```\n\nThe method listened to can be defined with `:via` option. By default any method is matched.\n\n```elixir\nTestServer.add(\"/\", via: :post)\n```\n\nA custom match function can be set with `:match` option:\n\n```elixir\nTestServer.add(\"/\", match: fn\n  %{params: %{\"a\" => \"1\"}} = _conn -> true\n  _conn -> false\nend)\n```\n\nWhen a route is matched it'll be removed from active routes list. The route will be triggered in the order they were added:\n\n```elixir\nTestServer.add(\"/\", via: :get, to: &Plug.Conn.send_resp(&1, 200, \"first\"))\nTestServer.add(\"/\", via: :get, to: &Plug.Conn.send_resp(&1, 200, \"second\"))\n\n{:ok, \"first\"} = fetch_request()\n{:ok, \"second\"} = fetch_request()\n```\n\nPlugs can be added to the pipeline with `TestServer.plug/1`. All plugs will run before any routes are matched. `Plug.Conn.fetch_query_params/1` is used if no plugs are set.\n\n```elixir\nTestServer.plug(fn conn ->\n  Plug.Conn.fetch_query_params(conn)\nend)\n\nTestServer.plug(fn conn ->\n  {:ok, body, _conn} = Plug.Conn.read_body(conn, [])\n\n  %{conn | body_params: Jason.decode!(body)}\nend)\n\nTestServer.plug(MyPlug)\n```","ref":"TestServer.html#module-usage"},{"type":"module","title":"HTTPS - TestServer","doc":"By default the test server is set up to serve plain HTTP. HTTPS can be enabled with the `:scheme` option when calling `TestServer.start/1`.\n\nCustom SSL certificates can also be used by defining the `:tls` option:\n\n```elixir\nTestServer.start(scheme: :https, tls: [keyfile: key, certfile: cert])\n```\n\nA self-signed certificate suite is automatically generated if you don't set the `:tls` options:\n\n```elixir\nTestServer.start(scheme: :https)\n\nreq_opts = [\n  connect_options: [\n    transport_opts: [cacerts: TestServer.x509_suite().cacerts],\n    protocols: [:http2]\n  ]\n]\n\nassert {:ok, %Req.Response{status: 200, body: \"HTTP/2\"}} =\n        Req.get(TestServer.url(), req_opts)\n```","ref":"TestServer.html#module-https"},{"type":"module","title":"WebSocket - TestServer","doc":"WebSocket endpoint can be set up by calling `TestServer.websocket_init/2`. By default, `TestServer.websocket_handle/2` will echo the message received. Messages can be send from the test server with `TestServer.websocket_info/2`.\n\n```elixir\ntest \"WebSocketClient\" do\n  {:ok, socket} = TestServer.websocket_init(\"/ws\")\n\n  :ok = TestServer.websocket_handle(socket)\n  :ok = TestServer.websocket_handle(socket, to: fn {:text, \"ping\"}, state -> {:reply, {:text, \"pong\"}, state} end)\n  :ok = TestServer.websocket_handle(socket, match: fn {:text, message}, _state -> message == \"hi\")\n\n  {:ok, client} = WebSocketClient.start_link(TestServer.url(\"/ws\"))\n\n  :ok = WebSocketClient.send(client, \"hello\")\n  {:ok, \"hello\"} = WebSocketClient.receive(client)\n\n  :ok = WebSocketClient.send(client, \"ping\")\n  {:ok, \"pong\"} = WebSocketClient.receive(client)\n\n  :ok = WebSocketClient.send(\"hi\")\n  {:ok, \"hi\"} = WebSocketClient.receive(client)\n\n  :ok = TestServer.websocket_info(socket, fn state -> {:reply, {:text, \"ping\"}, state} end)\n  {:ok, \"ping\"} = WebSocketClient.receive(client)\nend\n```\n\n*Note: WebSocket is not supported by the `:httpd` adapter.*","ref":"TestServer.html#module-websocket"},{"type":"module","title":"HTTP Server Adapter - TestServer","doc":"TestServer supports `Bandit`, `Plug.Cowboy`, and `:httpd` out of the box. The HTTP adapter will be selected in this order depending which is available in the dependencies. You can also explicitly set the http server in the configuration when calling `TestServer.start/1`:\n\n```elixir\nTestServer.start(http_server: {TestServer.HTTPServer.Bandit, []})\n```\n\nYou can create your own plug based HTTP Server Adapter by using the `TestServer.HTTPServer` behaviour.","ref":"TestServer.html#module-http-server-adapter"},{"type":"module","title":"IPv6 - TestServer","doc":"Use the `:ipfamily` option to test with IPv6 when starting the test server with `TestServer.start/1`:\n\n```elixir\nTestServer.start(ipfamily: :inet6)\n\nassert :ok =\n          TestServer.add(\"/\",\n            to: fn conn ->\n              assert conn.remote_ip == {0, 0, 0, 0, 0, 65_535, 32_512, 1}\n\n              Plug.Conn.resp(conn, 200, \"OK\")\n            end\n          )\n```","ref":"TestServer.html#module-ipv6"},{"type":"function","title":"TestServer.add/1","doc":"","ref":"TestServer.html#add/1"},{"type":"function","title":"TestServer.add/2","doc":"Adds a route to the current test server.\n\nMatching routes are handled FIFO (first in, first out). Any requests to\nroutes not added to the TestServer and any routes that isn't matched will\nraise an error in the test case.","ref":"TestServer.html#add/2"},{"type":"function","title":"Options - TestServer.add/2","doc":"* `:via`       - matches the route against some specific HTTP method(s)\n    specified as an atom, like `:get` or `:put`, or a list, like `[:get, :post]`.\n  * `:match`     - an anonymous function that will be called to see if a\n    route matches, defaults to matching with arguments of uri and `:via` option.\n  * `:to`        - a Plug or anonymous function that will be called when the\n    route matches, defaults to return the http scheme.","ref":"TestServer.html#add/2-options"},{"type":"function","title":"Examples - TestServer.add/2","doc":"TestServer.add(\"/\",\n      match: fn conn ->\n        conn.query_params[\"a\"] == \"1\"\n      end,\n      to: fn conn ->\n        Plug.Conn.resp(conn, 200, \"a = 1\")\n      end)\n\n    TestServer.add(\"/\", to: &Plug.Conn.resp(&1, 200, \"PONG\"))\n    TestServer.add(\"/\")\n\n    assert {:ok, %Req.Response{status: 200, body: \"PONG\"}} = Req.get(TestServer.url(\"/\"))\n    assert {:ok, %Req.Response{status: 200, body: \"HTTP/1.1\"}} = Req.post(TestServer.url(\"/\"))\n    assert {:ok, %Req.Response{status: 200, body: \"a = 1\"}} = Req.get(TestServer.url(\"/?a=1\"))","ref":"TestServer.html#add/2-examples"},{"type":"function","title":"TestServer.add/3","doc":"Adds a route to a test server instance.\n\nSee `add/2` for options.","ref":"TestServer.html#add/3"},{"type":"function","title":"TestServer.get_instance/0","doc":"Gets current test server instance if running.","ref":"TestServer.html#get_instance/0"},{"type":"function","title":"Examples - TestServer.get_instance/0","doc":"refute TestServer.get_instance()\n\n    {:ok, instance} = TestServer.start()\n\n    assert TestServer.get_instance() == instance","ref":"TestServer.html#get_instance/0-examples"},{"type":"type","title":"TestServer.instance/0","doc":"","ref":"TestServer.html#t:instance/0"},{"type":"function","title":"TestServer.plug/1","doc":"Adds a plug to the current test server.\n\nThis plug will be called for all requests before route is matched.","ref":"TestServer.html#plug/1"},{"type":"function","title":"Examples - TestServer.plug/1","doc":"TestServer.plug(MyPlug)\n\n    TestServer.plug(fn conn ->\n      {:ok, body, _conn} = Plug.Conn.read_body(conn, [])\n\n      %{conn | body_params: Jason.decode!(body)}\n    end)","ref":"TestServer.html#plug/1-examples"},{"type":"function","title":"TestServer.plug/2","doc":"Adds a route to a test server instance.\n\nSee `plug/1` for more.","ref":"TestServer.html#plug/2"},{"type":"type","title":"TestServer.route/0","doc":"","ref":"TestServer.html#t:route/0"},{"type":"type","title":"TestServer.stacktrace/0","doc":"","ref":"TestServer.html#t:stacktrace/0"},{"type":"function","title":"TestServer.start/1","doc":"Start a test server instance.\n\nThe instance will be terminated when the test case finishes.","ref":"TestServer.html#start/1"},{"type":"function","title":"Options - TestServer.start/1","doc":"* `:port`             - integer of port number, defaults to random port\n    that can be opened;\n  * `:scheme`           - an atom for the http scheme. Defaults to `:http`;\n  * `:http_server`      - HTTP server configuration. Defaults to\n    `{TestServer.HTTPServer.Bandit, []}`,\n    `{TestServer.HTTPServer.Plug.Cowboy, []}`, or\n    `{TestServer.HTTPServer.Httpd, []}` depending on which web server is\n    available in the project dependencies;\n  * `:tls`              - Passthru options for TLS configuration handled by\n    the webserver;\n  * `:ipfamily`         - The IP address type to use, either `:inet` or\n    `:inet6`. Defaults to `:inet`;","ref":"TestServer.html#start/1-options"},{"type":"function","title":"Examples - TestServer.start/1","doc":"TestServer.start(\n      scheme: :https,\n      ipfamily: :inet6,\n      http_server: {TestServer.HTTPServer.Bandit, [ip: :any]}\n    )\n\n    TestServer.add(\"/\",\n      to: fn conn ->\n        assert conn.remote_ip == {0, 0, 0, 0, 0, 65_535, 32_512, 1}\n\n        Plug.Conn.resp(conn, 200, to_string(Plug.Conn.get_http_protocol(conn)))\n      end\n    )\n\n    req_opts = [\n      connect_options: [\n        transport_opts: [cacerts: TestServer.x509_suite().cacerts],\n        protocols: [:http2]\n      ]\n    ]\n\n    assert {:ok, %Req.Response{status: 200, body: \"HTTP/2\"}} =\n            Req.get(TestServer.url(), req_opts)","ref":"TestServer.html#start/1-examples"},{"type":"function","title":"TestServer.stop/0","doc":"Shuts down the current test server.","ref":"TestServer.html#stop/0"},{"type":"function","title":"Examples - TestServer.stop/0","doc":"TestServer.start()\n    url = TestServer.url()\n    TestServer.stop()\n\n    assert {:error, %Req.TransportError{}} = Req.get(url, retry: false)","ref":"TestServer.html#stop/0-examples"},{"type":"function","title":"TestServer.stop/1","doc":"Shuts down a test server instance.","ref":"TestServer.html#stop/1"},{"type":"function","title":"TestServer.url/0","doc":"","ref":"TestServer.html#url/0"},{"type":"function","title":"TestServer.url/1","doc":"","ref":"TestServer.html#url/1"},{"type":"function","title":"TestServer.url/2","doc":"Produces a URL for current test server.","ref":"TestServer.html#url/2"},{"type":"function","title":"Options - TestServer.url/2","doc":"* `:host` - binary host value, it'll be added to inet for IP `127.0.0.1` and `::1`, defaults to `\"localhost\"`;","ref":"TestServer.html#url/2-options"},{"type":"function","title":"Examples - TestServer.url/2","doc":"TestServer.start(port: 4444)\n\n    assert TestServer.url() == \"http://localhost:4444\"\n    assert TestServer.url(\"/test\") == \"http://localhost:4444/test\"\n    assert TestServer.url(host: \"example.com\") == \"http://example.com:4444\"","ref":"TestServer.html#url/2-examples"},{"type":"function","title":"TestServer.url/3","doc":"Produces a URL for a test server instance.\n\nSee `url/2` for options.","ref":"TestServer.html#url/3"},{"type":"type","title":"TestServer.websocket_frame/0","doc":"","ref":"TestServer.html#t:websocket_frame/0"},{"type":"function","title":"TestServer.websocket_handle/1","doc":"","ref":"TestServer.html#websocket_handle/1"},{"type":"function","title":"TestServer.websocket_handle/2","doc":"Adds a message handler to a websocket instance.\n\nMessages are matched FIFO (first in, first out). Any messages not expected by\nTestServer or any message expectations not receiving a message will raise an\nerror in the test case.","ref":"TestServer.html#websocket_handle/2"},{"type":"function","title":"Options - TestServer.websocket_handle/2","doc":"* `:match`     - an anonymous function that will be called to see if a\n    message matches, defaults to matching anything.\n  * `:to`        - an anonymous function that will be called when the message\n    matches, defaults to returning received message.","ref":"TestServer.html#websocket_handle/2-options"},{"type":"function","title":"Examples - TestServer.websocket_handle/2","doc":"{:ok, socket} = TestServer.websocket_init(\"/ws\")\n\n    TestServer.websocket_handle(\n      socket,\n      to: fn _frame, state ->\n        {:reply, {:text, \"pong\"}, state}\n      end,\n      match: fn frame, _state ->\n        frame == {:text, \"ping\"}\n      end)\n\n    TestServer.websocket_handle(socket)\n\n    {:ok, client} = WebSocketClient.start_link(TestServer.url(\"/ws\"))\n\n    assert WebSocketClient.send_message(client, \"echo\") == {:ok, \"echo\"}\n    assert WebSocketClient.send_message(client, \"ping\") == {:ok, \"pong\"}","ref":"TestServer.html#websocket_handle/2-examples"},{"type":"function","title":"TestServer.websocket_info/2","doc":"Sends an message to a websocket instance.","ref":"TestServer.html#websocket_info/2"},{"type":"function","title":"Examples - TestServer.websocket_info/2","doc":"{:ok, socket} = TestServer.websocket_init(\"/ws\")\n    {:ok, client} = WebSocketClient.start_link(TestServer.url(\"/ws\"))\n\n    assert TestServer.websocket_info(socket, fn state ->\n      {:reply, {:text, \"hello\"}, state}\n    end) == :ok\n\n    assert WebSocketClient.receive_message(client) == {:ok, \"hello\"}","ref":"TestServer.html#websocket_info/2-examples"},{"type":"function","title":"TestServer.websocket_init/1","doc":"","ref":"TestServer.html#websocket_init/1"},{"type":"function","title":"TestServer.websocket_init/2","doc":"Adds a websocket route to current test server.\n\nThe `:to` option can be overridden the same way as for `add/2`, and will be\ncalled during the HTTP handshake. If the `conn.state` is `:unset` the\nwebsocket will be initiated otherwise response is returned as-is.","ref":"TestServer.html#websocket_init/2"},{"type":"function","title":"Options - TestServer.websocket_init/2","doc":"Takes the same options as `add/2`, except `:to`.","ref":"TestServer.html#websocket_init/2-options"},{"type":"function","title":"Examples - TestServer.websocket_init/2","doc":"{:ok, socket} = TestServer.websocket_init(\"/ws\")\n    TestServer.websocket_handle(socket)\n\n    assert {:ok, client} = WebSocketClient.start_link(TestServer.url(\"/ws\"))\n    assert WebSocketClient.send_message(client, \"echo\") == {:ok, \"echo\"}\n\n`:via` and `:match` are called during the HTTP handshake:\n\n    TestServer.websocket_init(\"/ws\", via: :get, match: fn conn ->\n      conn.params[\"token\"] == \"secret\"\n    end)\n\n    assert {:ok, _client} = WebSocketClient.start_link(TestServer.url(\"/ws?token=secret\"))\n\n`:to` option is also called during the HTTP handshake:\n\n    TestServer.websocket_init(\"/ws\",\n      to: fn conn ->\n        Plug.Conn.send_resp(conn, 403, \"Forbidden\")\n      end\n    )\n\n    assert {:error, %WebSockex.RequestError{code: 403}} =\n            WebSocketClient.start_link(TestServer.url(\"/ws\"))","ref":"TestServer.html#websocket_init/2-examples"},{"type":"function","title":"TestServer.websocket_init/3","doc":"Adds a websocket route to a test server.\n\nSee `websocket_init/2` for options.","ref":"TestServer.html#websocket_init/3"},{"type":"type","title":"TestServer.websocket_reply/0","doc":"","ref":"TestServer.html#t:websocket_reply/0"},{"type":"type","title":"TestServer.websocket_socket/0","doc":"","ref":"TestServer.html#t:websocket_socket/0"},{"type":"type","title":"TestServer.websocket_state/0","doc":"","ref":"TestServer.html#t:websocket_state/0"},{"type":"function","title":"TestServer.x509_suite/0","doc":"Fetches the generated x509 suite for the current test server.","ref":"TestServer.html#x509_suite/0"},{"type":"function","title":"Examples - TestServer.x509_suite/0","doc":"TestServer.start(scheme: :https)\n    TestServer.add(\"/\")\n\n    cacerts = TestServer.x509_suite().cacerts\n    req_opts = [connect_options: [transport_opts: [cacerts: cacerts]]]\n\n    assert {:ok, %Req.Response{status: 200, body: \"HTTP/1.1\"}} =\n            Req.get(TestServer.url(), req_opts)","ref":"TestServer.html#x509_suite/0-examples"},{"type":"function","title":"TestServer.x509_suite/1","doc":"Fetches the generated x509 suite for a test server instance.\n\nSee `x509_suite/0` for more.","ref":"TestServer.html#x509_suite/1"},{"type":"behaviour","title":"TestServer.HTTPServer","doc":"HTTP server adapter module.","ref":"TestServer.HTTPServer.html"},{"type":"behaviour","title":"Usage - TestServer.HTTPServer","doc":"defmodule MyApp.MyHTTPServer do\n      @behaviour TestServer.HTTPServer\n\n      @impl TestServer.HTTPServer\n      def start(instance, port, scheme, tls_options, server_options) do\n        my_http_server_options =\n          server_options\n          |> Keyword.put(:port, port)\n          |> Keyword.put_new(:ipfamily, options[:ipfamily])\n\n        case MyHTTPServer.start(my_http_server_options) do\n          {:ok, pid} -> {:ok, pid, my_http_server_options}\n          {:error, error} -> {:error, error}\n        end\n      end\n\n      @impl TestServer.HTTPServer\n      def stop(instance, server_options), do: MyHTTPServer.stop()\n\n      @impl TestServer.HTTPServer\n      def get_socket_pid(conn), do: conn.owner\n    end","ref":"TestServer.HTTPServer.html#module-usage"},{"type":"callback","title":"TestServer.HTTPServer.get_socket_pid/1","doc":"","ref":"TestServer.HTTPServer.html#c:get_socket_pid/1"},{"type":"type","title":"TestServer.HTTPServer.instance/0","doc":"","ref":"TestServer.HTTPServer.html#t:instance/0"},{"type":"type","title":"TestServer.HTTPServer.options/0","doc":"","ref":"TestServer.HTTPServer.html#t:options/0"},{"type":"type","title":"TestServer.HTTPServer.port_number/0","doc":"","ref":"TestServer.HTTPServer.html#t:port_number/0"},{"type":"type","title":"TestServer.HTTPServer.scheme/0","doc":"","ref":"TestServer.HTTPServer.html#t:scheme/0"},{"type":"type","title":"TestServer.HTTPServer.server_options/0","doc":"","ref":"TestServer.HTTPServer.html#t:server_options/0"},{"type":"callback","title":"TestServer.HTTPServer.start/5","doc":"","ref":"TestServer.HTTPServer.html#c:start/5"},{"type":"callback","title":"TestServer.HTTPServer.stop/2","doc":"","ref":"TestServer.HTTPServer.html#c:stop/2"},{"type":"module","title":"TestServer.HTTPServer.Bandit","doc":"HTTP server adapter using `Bandit`.\n\nBy default only one acceptor process is started which is enough for\ntesting. This adapter will be used by default if `Bandit` is loaded in the\nproject.","ref":"TestServer.HTTPServer.Bandit.html"},{"type":"module","title":"Usage - TestServer.HTTPServer.Bandit","doc":"TestServer.start(\n      http_server: {TestServer.HTTPServer.Bandit, bandit_options}\n    )","ref":"TestServer.HTTPServer.Bandit.html#module-usage"},{"type":"module","title":"TestServer.HTTPServer.Httpd","doc":"HTTP server adapter using `:httpd`.\n\nThis adapter will be used by default if there is no `Bandit` or\n`Plug.Cowboy` loaded in the project.","ref":"TestServer.HTTPServer.Httpd.html"},{"type":"module","title":"Usage - TestServer.HTTPServer.Httpd","doc":"TestServer.start(\n      http_server: {TestServer.HTTPServer.Httpd, httpd_options}\n    )","ref":"TestServer.HTTPServer.Httpd.html#module-usage"},{"type":"module","title":"TestServer.HTTPServer.Plug.Cowboy","doc":"HTTP server adapter using `Plug.Cowboy`.\n\nThis adapter will be used by default if `Bandit` is not loaded and\n`Plug.Cowboy` is loaded in the project.","ref":"TestServer.HTTPServer.Plug.Cowboy.html"},{"type":"module","title":"Usage - TestServer.HTTPServer.Plug.Cowboy","doc":"TestServer.start(\n      http_server: {TestServer.HTTPServer.Plug.Cowboy, cowboy_options}\n    )","ref":"TestServer.HTTPServer.Plug.Cowboy.html#module-usage"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"CHANGELOG.html"},{"type":"extras","title":"v0.1.21 (2025-06-20) - Changelog","doc":"- Fixed bug with message emitted in Bandit 1.7.0","ref":"CHANGELOG.html#v0-1-21-2025-06-20"},{"type":"extras","title":"v0.1.20 (2025-02-28) - Changelog","doc":"- Include `:inets` in `:extra_applications` to prevent compilation issue with `TestServer.HTTPServer.Httpd`","ref":"CHANGELOG.html#v0-1-20-2025-02-28"},{"type":"extras","title":"v0.1.19 (2025-02-27) - Changelog","doc":"- Allow `:to` plug to be set for `TestServer.websocket_init/3` for handshake","ref":"CHANGELOG.html#v0-1-19-2025-02-27"},{"type":"extras","title":"v0.1.18 (2024-12-29) - Changelog","doc":"- Limit number of Bandit acceptors to 1 to improve performance","ref":"CHANGELOG.html#v0-1-18-2024-12-29"},{"type":"extras","title":"v0.1.17 (2024-09-30) - Changelog","doc":"- Fixed invalid spec for `TestServer.url/1`","ref":"CHANGELOG.html#v0-1-17-2024-09-30"},{"type":"extras","title":"v0.1.16 (2024-04-02) - Changelog","doc":"- Fixed breaking changes with Bandit 1.4","ref":"CHANGELOG.html#v0-1-16-2024-04-02"},{"type":"extras","title":"v0.1.15 (2024-02-26) - Changelog","doc":"- Validates `:http_server` option","ref":"CHANGELOG.html#v0-1-15-2024-02-26"},{"type":"extras","title":"v0.1.14 (2023-11-18) - Changelog","doc":"- Fixed compiler warning in `TestServer.Instance`","ref":"CHANGELOG.html#v0-1-14-2023-11-18"},{"type":"extras","title":"v0.1.13 (2023-08-26) - Changelog","doc":"- Fixed controlling process issues related to using the Bandit HTTP/2 adapter calling `Plug.Conn` functions in plug callbacks","ref":"CHANGELOG.html#v0-1-13-2023-08-26"},{"type":"extras","title":"v0.1.12 (2023-04-29) - Changelog","doc":"- Fixed breaking change to options in Bandit 0.7.6","ref":"CHANGELOG.html#v0-1-12-2023-04-29"},{"type":"extras","title":"v0.1.11 (2023-03-27) - Changelog","doc":"- Now uses `Plug.Conn.resp/3` instead of `Plug.Conn.send_resp/3` to prevent controlling process issue in Bandit\n- Silenced Bandit logs\n- Silence TLS notice logs","ref":"CHANGELOG.html#v0-1-11-2023-03-27"},{"type":"extras","title":"v0.1.10 (2023-02-22) - Changelog","doc":"- `:httpd` server adapter now can read request body","ref":"CHANGELOG.html#v0-1-10-2023-02-22"},{"type":"extras","title":"v0.1.9 (2023-02-18) - Changelog","doc":"- `:httpd` server adapter now parses remote ip to tuple format\n- `:httpd` server adapter now parses host from host header\n- Specifying `:host` now also binds the hostname to IPv6 loopback\n- Added `:ipfamily` option to set IP address type to use","ref":"CHANGELOG.html#v0-1-9-2023-02-18"},{"type":"extras","title":"v0.1.8 (2023-02-10) - Changelog","doc":"- Support Bandit and httpd web server\n- BREAKING CHANGE: SSL certificate settings have been moved to the `:tls` option","ref":"CHANGELOG.html#v0-1-8-2023-02-10"},{"type":"extras","title":"v0.1.7 (2022-10-06) - Changelog","doc":"- The specified port is checked to ensure is in valid range","ref":"CHANGELOG.html#v0-1-7-2022-10-06"},{"type":"extras","title":"v0.1.6 (2022-09-22) - Changelog","doc":"- Added suspended routes and web socket handlers to error messages","ref":"CHANGELOG.html#v0-1-6-2022-09-22"},{"type":"extras","title":"v0.1.5 (2022-09-13) - Changelog","doc":"- `TestServer.websocket_info/2` now takes the callback function as second argument","ref":"CHANGELOG.html#v0-1-5-2022-09-13"},{"type":"extras","title":"v0.1.4 (2022-09-13) - Changelog","doc":"- WebSocket support","ref":"CHANGELOG.html#v0-1-4-2022-09-13"},{"type":"extras","title":"v0.1.3 (2022-09-12) - Changelog","doc":"- Improved multi-instance handling\n- Support for pre-match plugs","ref":"CHANGELOG.html#v0-1-3-2022-09-12"},{"type":"extras","title":"v0.1.2 (2022-09-12) - Changelog","doc":"- Better formatting of errors","ref":"CHANGELOG.html#v0-1-2-2022-09-12"},{"type":"extras","title":"v0.1.1 (2022-09-11) - Changelog","doc":"- `TestServer.url/2` no longer autostarts the test server","ref":"CHANGELOG.html#v0-1-1-2022-09-11"},{"type":"extras","title":"v0.1.0 (2022-09-11) - Changelog","doc":"- Initial release","ref":"CHANGELOG.html#v0-1-0-2022-09-11"}],"content_type":"text/markdown","proglang":"elixir","producer":{"name":"ex_doc","version":"0.38.2"}}